==> edge-login-ui-rn-3.4.1.tgz: package/lib/components/ui4/CardUi4.js <==
/**
 * IMPORTANT: Changes in this file MUST be synced with edge-react-gui!
 */
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import * as React from 'react';
import { StyleSheet, TouchableOpacity, View } from 'react-native';
import LinearGradient from 'react-native-linear-gradient';
import { cacheStyles } from 'react-native-patina';
import AntDesignIcon from 'react-native-vector-icons/AntDesign';
import { useHandler } from '../../hooks/useHandler';
import { triggerHaptic } from '../../util/haptic';
import { fixSides, mapSides, sidesToMargin, sidesToPadding } from '../../util/sides';
import { showError } from '../services/AirshipInstance';
import { useTheme } from '../services/ThemeContext';
import { SectionView } from './SectionViewUi4';
/**
 * Rounded card
 *
 * sections: Automatically adds horizontal dividers between each child, aligned
 * in a column layout. Adds no dividers if only one child is given.
 *
 * gradientBackground/nodeBackground: For specifying a complex background
 * that can include embedded images or any other component.
 *
 * onClose: If specified, adds a close button
 */
export const CardUi4 = (props) => {
    const { children, icon, marginRem, paddingRem, overlay, sections, gradientBackground, nodeBackground, onClose, onLongPress, onPress } = props;
    const theme = useTheme();
    const styles = getStyles(theme);
    const margin = sidesToMargin(mapSides(fixSides(marginRem, 0.5), theme.rem));
    const padding = sidesToPadding(mapSides(fixSides(paddingRem, 0.5), theme.rem));
    const isPressable = onPress != null || onLongPress != null;
    const handlePress = useHandler(() => __awaiter(void 0, void 0, void 0, function* () {
        if (onPress != null) {
            triggerHaptic('impactLight');
            try {
                yield onPress();
            }
            catch (err) {
                showError(err);
            }
        }
    }));
    const handleLongPress = useHandler(() => __awaiter(void 0, void 0, void 0, function* () {
        if (onLongPress != null) {
            triggerHaptic('impactLight');
            try {
                yield onLongPress();
            }
            catch (err) {
                showError(err);
            }
        }
    }));
    const handleClose = useHandler(() => {
        triggerHaptic('impactLight');
    });
    const background = (React.createElement(View, { style: styles.backgroundFill },
        nodeBackground,
        gradientBackground == null ? null : (React.createElement(LinearGradient, Object.assign({}, gradientBackground, { style: StyleSheet.absoluteFill })))));
    const maybeIcon = icon == null ? null : React.createElement(View, { style: styles.iconContainer }, icon);
    const content = sections ? React.createElement(SectionView, null, children) : children;
    const maybeCloseButton = onClose == null ? null : (React.createElement(TouchableOpacity, { style: styles.cornerContainer, onPress: handleClose },
        React.createElement(AntDesignIcon, { color: theme.primaryText, name: "close", size: theme.rem(1.25) })));
    const maybeOverlay = overlay == null ? null : (React.createElement(View, { style: styles.overlayContainer }, overlay));
    const allContent = icon == null ? (React.createElement(React.Fragment, null,
        background,
        content,
        maybeCloseButton,
        maybeOverlay)) : (React.createElement(React.Fragment, null,
        background,
        React.createElement(View, { style: styles.rowContainer },
            maybeIcon,
            content),
        maybeCloseButton,
        maybeOverlay));
    return isPressable ? (React.createElement(TouchableOpacity, { accessible: false, onPress: handlePress, onLongPress: handleLongPress, style: [styles.cardContainer, margin, padding] }, allContent)) : (React.createElement(View, { style: [styles.cardContainer, margin, padding] }, allContent));
};
const getStyles = cacheStyles((theme) => ({
    backgroundFill: Object.assign(Object.assign({}, StyleSheet.absoluteFillObject), { borderRadius: theme.cardBorderRadius, backgroundColor: theme.cardBaseColor, overflow: 'hidden' }),
    cardContainer: {
        borderRadius: theme.cardBorderRadius,
        flex: 1
    },
    cornerContainer: {
        margin: theme.rem(1),
        top: 0,
        right: 0,
        position: 'absolute'
    },
    overlayContainer: Object.assign(Object.assign({}, StyleSheet.absoluteFillObject), { alignItems: 'center', backgroundColor: theme.cardOverlayDisabled, borderRadius: theme.cardBorderRadius, justifyContent: 'center', margin: 2, pointerEvents: 'none' }),
    rowContainer: {
        flex: 1,
        flexDirection: 'row',
        alignItems: 'center'
    },
    iconContainer: {
        margin: theme.rem(0.25),
        justifyContent: 'center',
        alignContent: 'center'
    }
}));

==> edge-login-ui-rn-3.17.0.tgz: package/lib/components/ui4/CardUi4.js <==
/**
 * IMPORTANT: Changes in this file MUST be synced with edge-react-gui!
 */
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import * as React from 'react';
import { StyleSheet, View } from 'react-native';
import LinearGradient from 'react-native-linear-gradient';
import { cacheStyles } from 'react-native-patina';
import AntDesignIcon from 'react-native-vector-icons/AntDesign';
import { useHandler } from '../../hooks/useHandler';
import { triggerHaptic } from '../../util/haptic';
import { fixSides, mapSides, sidesToMargin, sidesToPadding } from '../../util/sides';
import { EdgeTouchableOpacity } from '../common/EdgeTouchableOpacity';
import { showError } from '../services/AirshipInstance';
import { useTheme } from '../services/ThemeContext';
import { SectionView } from './SectionViewUi4';
/**
 * Rounded card
 *
 * sections: Automatically adds horizontal dividers between each child, aligned
 * in a column layout. Adds no dividers if only one child is given.
 *
 * gradientBackground/nodeBackground: For specifying a complex background
 * that can include embedded images or any other component.
 *
 * onClose: If specified, adds a close button
 */
export const CardUi4 = (props) => {
    const { children, icon, marginRem, paddingRem, overlay, sections, gradientBackground, nodeBackground, onClose, onLongPress, onPress } = props;
    const theme = useTheme();
    const styles = getStyles(theme);
    const margin = sidesToMargin(mapSides(fixSides(marginRem, 0.5), theme.rem));
    const padding = sidesToPadding(mapSides(fixSides(paddingRem, 0.5), theme.rem));
    const isPressable = onPress != null || onLongPress != null;
    const handlePress = useHandler(() => __awaiter(void 0, void 0, void 0, function* () {
        if (onPress != null) {
            triggerHaptic('impactLight');
            try {
                yield onPress();
            }
            catch (err) {
                showError(err);
            }
        }
    }));
    const handleLongPress = useHandler(() => __awaiter(void 0, void 0, void 0, function* () {
        if (onLongPress != null) {
            triggerHaptic('impactLight');
            try {
                yield onLongPress();
            }
            catch (err) {
                showError(err);
            }
        }
    }));
    const handleClose = useHandler(() => {
        triggerHaptic('impactLight');
    });
    const background = (React.createElement(View, { style: styles.backgroundFill },
        nodeBackground,
        gradientBackground == null ? null : (React.createElement(LinearGradient, Object.assign({}, gradientBackground, { style: StyleSheet.absoluteFill })))));
    const maybeIcon = icon == null ? null : React.createElement(View, { style: styles.iconContainer }, icon);
    const content = sections ? React.createElement(SectionView, null, children) : children;
    const maybeCloseButton = onClose == null ? null : (React.createElement(EdgeTouchableOpacity, { style: styles.cornerContainer, onPress: handleClose },
        React.createElement(AntDesignIcon, { color: theme.primaryText, name: "close", size: theme.rem(1.25) })));
    const maybeOverlay = overlay == null ? null : (React.createElement(View, { style: styles.overlayContainer }, overlay));
    const allContent = icon == null ? (React.createElement(React.Fragment, null,
        background,
        content,
        maybeCloseButton,
        maybeOverlay)) : (React.createElement(React.Fragment, null,
        background,
        React.createElement(View, { style: styles.rowContainer },
            maybeIcon,
            content),
        maybeCloseButton,
        maybeOverlay));
    return isPressable ? (React.createElement(EdgeTouchableOpacity, { accessible: false, onPress: handlePress, onLongPress: handleLongPress, style: [styles.cardContainer, margin, padding] }, allContent)) : (React.createElement(View, { style: [styles.cardContainer, margin, padding] }, allContent));
};
const getStyles = cacheStyles((theme) => ({
    backgroundFill: Object.assign(Object.assign({}, StyleSheet.absoluteFillObject), { borderRadius: theme.cardBorderRadius, backgroundColor: theme.cardBaseColor, overflow: 'hidden' }),
    cardContainer: {
        borderRadius: theme.cardBorderRadius,
        flex: 1
    },
    cornerContainer: {
        margin: theme.rem(1),
        top: 0,
        right: 0,
        position: 'absolute'
    },
    overlayContainer: Object.assign(Object.assign({}, StyleSheet.absoluteFillObject), { alignItems: 'center', backgroundColor: theme.cardOverlayDisabled, borderRadius: theme.cardBorderRadius, justifyContent: 'center', margin: 2, pointerEvents: 'none' }),
    rowContainer: {
        flex: 1,
        flexDirection: 'row',
        alignItems: 'center'
    },
    iconContainer: {
        margin: theme.rem(0.25),
        justifyContent: 'center',
        alignContent: 'center'
    }
}));
